==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand.md <==
# AwsSystemsManagerRunCommand


```text
aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand
```

```text
include('aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')
```



| Illustration | AwsSystemsManagerRunCommand | AwsSystemsManagerRunCommandCard | AwsSystemsManagerRunCommandGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand.png) | ![illustration for AwsSystemsManagerRunCommand](../../../aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand.Local.png) | ![illustration for AwsSystemsManagerRunCommandCard](../../../aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommandCard.Local.png) | ![illustration for AwsSystemsManagerRunCommandGroup](../../../aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommandGroup.Local.png) |




## AwsSystemsManagerRunCommand

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommand
include('aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommand('AwsSystemsManagerRunCommand', 'Aws Systems Manager Run Command', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommand
include('aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommand('AwsSystemsManagerRunCommand', 'Aws Systems Manager Run Command', 'an optional tech label')
@enduml
```

## AwsSystemsManagerRunCommandCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommandCard
include('aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommandCard('AwsSystemsManagerRunCommandCard', 'Aws Systems Manager Run Command Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommandCard
include('aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommandCard('AwsSystemsManagerRunCommandCard', 'Aws Systems Manager Run Command Card', 'an optional description')
@enduml
```

## AwsSystemsManagerRunCommandGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommandGroup
include('aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommandGroup('AwsSystemsManagerRunCommandGroup', 'Aws Systems Manager Run Command Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommandGroup
include('aws-q2-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommandGroup('AwsSystemsManagerRunCommandGroup', 'Aws Systems Manager Run Command Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand.md <==
# AwsSystemsManagerRunCommand


```text
aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand
```

```text
include('aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')
```



| Illustration | AwsSystemsManagerRunCommand | AwsSystemsManagerRunCommandCard | AwsSystemsManagerRunCommandGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand.png) | ![illustration for AwsSystemsManagerRunCommand](../../../aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand.Local.png) | ![illustration for AwsSystemsManagerRunCommandCard](../../../aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommandCard.Local.png) | ![illustration for AwsSystemsManagerRunCommandGroup](../../../aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommandGroup.Local.png) |




## AwsSystemsManagerRunCommand

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommand
include('aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommand('AwsSystemsManagerRunCommand', 'Aws Systems Manager Run Command', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommand
include('aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommand('AwsSystemsManagerRunCommand', 'Aws Systems Manager Run Command', 'an optional tech label', 'an optional description')
@enduml
```

## AwsSystemsManagerRunCommandCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommandCard
include('aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommandCard('AwsSystemsManagerRunCommandCard', 'Aws Systems Manager Run Command Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommandCard
include('aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommandCard('AwsSystemsManagerRunCommandCard', 'Aws Systems Manager Run Command Card', 'an optional description')
@enduml
```

## AwsSystemsManagerRunCommandGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommandGroup
include('aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommandGroup('AwsSystemsManagerRunCommandGroup', 'Aws Systems Manager Run Command Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerRunCommandGroup
include('aws-q1-2022/Resource/ManagementGovernance/AwsSystemsManagerRunCommand')

' renders the element
AwsSystemsManagerRunCommandGroup('AwsSystemsManagerRunCommandGroup', 'Aws Systems Manager Run Command Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
